package com.mediaworx.b4f.opencms.contenttypes.widgets;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.opencms.widgets.I_CmsWidget;

/**
 * Custom widget providing a text input field that uses spell checking (the input tag's attribute "spellcheck" ist set
 * to <code>true</code>).<br />
 * Works in concert with the JavaScript file
 * com.mediaworx.b4f.opencms.contenttypes/resources/spellcheckedtextinput/SpellcheckedTextInputWidget.js
 */
public class SpellcheckedTextInputWidget extends B4fWidget {

	private static final Log LOG = LogFactory.getLog(SpellcheckedTextInputWidget.class);

	/** JavaScript files to be included for the widget */
	private static final String[] JSPATHS = {
			"spellcheckedtextinput/SpellcheckedTextInputWidget.js"
	};

	/** CSS files to be included for the widget */
	private static final String[] CSSPATHS = {
			"spellcheckedtextinput/SpellcheckedTextInputWidget.css"
	};

	/** default constructor, necessary for registering the class */
	public SpellcheckedTextInputWidget() {
		this("");
	}

	/**
	 * creates a new SpellcheckedTextInputWidget widget with the provided configuration
	 *
	 * @param configuration configuration string (from the attribute "configuration" in the xsd file)
	 */
	public SpellcheckedTextInputWidget(String configuration) {
		super(configuration);
	}

	/**
	 * returns the widget name and identifier that is also used in the client side javascript
	 * @return "SpellcheckedTextInputWidget"
	 */
	@Override
	public String getWidgetName() {
		return "SpellcheckedTextInputWidget";
	}

	/**
	 * returns the name of the JavaScript function that is called to initialize the widget
	 * @return "b4fSpellcheckedTextInputWidgetInitializationCall"
	 */
	@Override
	public String getInitCall() {
		if (LOG.isTraceEnabled()) {
			LOG.trace("getInitCall called");
		}
		// return the javascript function name that initializes the widget
		return "b4fSpellcheckedTextInputWidgetInitializationCall";
	}


	/**
	 * returns paths to css files (relative to {@link #RESOURCES_PATH}) that will be integrated in the xml content
	 * editor and the inline editor
	 * @return String array containing css paths
	 */
	@Override
	public String[] getCssPaths() {
		return CSSPATHS;
	}

	/**
	 * returns paths to JavaScript files (relative to {@link #RESOURCES_PATH}) that will be integrated in the xml
	 * content editor and the inline editor
	 * @return String array containing JavaScript paths
	 */
	@Override
	public String[] getJsPaths() {
		return JSPATHS;
	}

	/** Creates a new SpellcheckedTextInputWidget instance */
	@Override
	public I_CmsWidget newInstance() {
		return new SpellcheckedTextInputWidget(getConfiguration());
	}

}
